@@ -5,6 +5,7 @@ from asyncio import Task
 from typing import TYPE_CHECKING, Any, Callable, Coroutine, Union
 
 from github.PullRequest import PullRequest
+from github.Repository import Repository
 
 from webhook_server.libs.check_run_handler import CheckRunHandler
 from webhook_server.libs.labels_handler import LabelsHandler
@@ -44,8 +45,8 @@ class IssueCommentHandler:
 
         self.hook_data = self.github_webhook.hook_data
         self.logger = self.github_webhook.logger
-        self.log_prefix = self.github_webhook.log_prefix
-        self.repository = self.github_webhook.repository
+        self.log_prefix: str = self.github_webhook.log_prefix
+        self.repository: Repository = self.github_webhook.repository
         self.labels_handler = LabelsHandler(
             github_webhook=self.github_webhook, owners_file_handler=self.owners_file_handler
         )
@@ -59,11 +60,14 @@ class IssueCommentHandler:
 
     async def process_comment_webhook_data(self, pull_request: PullRequest) -> None:
         comment_action = self.hook_data["action"]
+        self.logger.step(f"{self.log_prefix} Starting issue comment processing: action={comment_action}")  # type: ignore
 
         if comment_action in ("edited", "deleted"):
+            self.logger.step(f"{self.log_prefix} Skipping comment processing: action is {comment_action}")  # type: ignore
             self.logger.debug(f"{self.log_prefix} Not processing comment. action is {comment_action}")
             return
 
+        self.logger.step(f"{self.log_prefix} Processing issue comment for issue {self.hook_data['issue']['number']}")  # type: ignore
         self.logger.info(f"{self.log_prefix} Processing issue {self.hook_data['issue']['number']}")
 
         body: str = self.hook_data["comment"]["body"]
@@ -74,8 +78,12 @@ class IssueCommentHandler:
 
         _user_commands: list[str] = [_cmd.strip("/") for _cmd in body.strip().splitlines() if _cmd.startswith("/")]
 
+        if _user_commands:
+            self.logger.step(f"{self.log_prefix} Found {len(_user_commands)} user commands: {_user_commands}")  # type: ignore
+
         user_login: str = self.hook_data["sender"]["login"]
         for user_command in _user_commands:
+            self.logger.step(f"{self.log_prefix} Executing user command: /{user_command} by {user_login}")  # type: ignore
             await self.user_commands(
                 pull_request=pull_request,
                 command=user_command,
