@@ -1,5 +1,6 @@
 import asyncio
 import contextlib
+import re
 import shutil
 from typing import TYPE_CHECKING, Any, AsyncGenerator
 from uuid import uuid4
@@ -7,6 +8,7 @@ from uuid import uuid4
 import shortuuid
 from github.Branch import Branch
 from github.PullRequest import PullRequest
+from github.Repository import Repository
 
 from webhook_server.libs.check_run_handler import CheckRunHandler
 from webhook_server.libs.owners_files_handler import OwnersFileHandler
@@ -15,6 +17,7 @@ from webhook_server.utils.constants import (
     CHERRY_PICKED_LABEL_PREFIX,
     CONVENTIONAL_TITLE_STR,
     PRE_COMMIT_STR,
+    PREK_STR,
     PYTHON_MODULE_INSTALL_STR,
     TOX_STR,
 )
@@ -30,8 +33,8 @@ class RunnerHandler:
         self.owners_file_handler = owners_file_handler or OwnersFileHandler(github_webhook=self.github_webhook)
         self.hook_data = self.github_webhook.hook_data
         self.logger = self.github_webhook.logger
-        self.log_prefix = self.github_webhook.log_prefix
-        self.repository = self.github_webhook.repository
+        self.log_prefix: str = self.github_webhook.log_prefix
+        self.repository: Repository = self.github_webhook.repository
 
         self.check_run_handler = CheckRunHandler(
             github_webhook=self.github_webhook, owners_file_handler=self.owners_file_handler
@@ -176,8 +179,11 @@ class RunnerHandler:
 
     async def run_tox(self, pull_request: PullRequest) -> None:
         if not self.github_webhook.tox:
+            self.logger.debug(f"{self.log_prefix} Tox not configured for this repository")
             return
 
+        self.logger.step(f"{self.log_prefix} Starting tox tests execution")  # type: ignore
+
         if await self.check_run_handler.is_check_run_in_progress(check_run=TOX_STR):
             self.logger.debug(f"{self.log_prefix} Check run is in progress, re-running {TOX_STR}.")
 
@@ -192,8 +198,11 @@ class RunnerHandler:
             tests = _tox_tests.replace(" ", "")
             cmd += f" -e {tests}"
 
+        self.logger.step(f"{self.log_prefix} Setting tox check status to in-progress")  # type: ignore
         await self.check_run_handler.set_run_tox_check_in_progress()
         self.logger.debug(f"{self.log_prefix} Tox command to run: {cmd}")
+
+        self.logger.step(f"{self.log_prefix} Preparing repository clone for tox execution")  # type: ignore
         async with self._prepare_cloned_repo_dir(clone_repo_dir=clone_repo_dir, pull_request=pull_request) as _res:
             output: dict[str, Any] = {
                 "title": "Tox",
@@ -201,28 +210,39 @@ class RunnerHandler:
                 "text": None,
             }
             if not _res[0]:
+                self.logger.error(f"{self.log_prefix} Repository preparation failed for tox")
                 output["text"] = self.check_run_handler.get_check_run_text(out=_res[1], err=_res[2])
                 return await self.check_run_handler.set_run_tox_check_failure(output=output)
 
+            self.logger.step(f"{self.log_prefix} Executing tox command")  # type: ignore
             rc, out, err = await run_command(command=cmd, log_prefix=self.log_prefix)
 
             output["text"] = self.check_run_handler.get_check_run_text(err=err, out=out)
 
             if rc:
+                self.logger.step(f"{self.log_prefix} Tox tests completed successfully")  # type: ignore
                 return await self.check_run_handler.set_run_tox_check_success(output=output)
             else:
+                self.logger.step(f"{self.log_prefix} Tox tests failed")  # type: ignore
                 return await self.check_run_handler.set_run_tox_check_failure(output=output)
 
     async def run_pre_commit(self, pull_request: PullRequest) -> None:
         if not self.github_webhook.pre_commit:
+            self.logger.debug(f"{self.log_prefix} Pre-commit not configured for this repository")
             return
 
+        self.logger.step(f"{self.log_prefix} Starting pre-commit checks execution")  # type: ignore
+
         if await self.check_run_handler.is_check_run_in_progress(check_run=PRE_COMMIT_STR):
             self.logger.debug(f"{self.log_prefix} Check run is in progress, re-running {PRE_COMMIT_STR}.")
 
         clone_repo_dir = f"{self.github_webhook.clone_repo_dir}-{uuid4()}"
-        cmd = f" uvx --directory {clone_repo_dir} {PRE_COMMIT_STR} run --all-files"
+        cmd = f" uvx --directory {clone_repo_dir} {PREK_STR} run --all-files"
+
+        self.logger.step(f"{self.log_prefix} Setting pre-commit check status to in-progress")  # type: ignore
         await self.check_run_handler.set_run_pre_commit_check_in_progress()
+
+        self.logger.step(f"{self.log_prefix} Preparing repository clone for pre-commit execution")  # type: ignore
         async with self._prepare_cloned_repo_dir(pull_request=pull_request, clone_repo_dir=clone_repo_dir) as _res:
             output: dict[str, Any] = {
                 "title": "Pre-Commit",
@@ -230,16 +250,20 @@ class RunnerHandler:
                 "text": None,
             }
             if not _res[0]:
+                self.logger.error(f"{self.log_prefix} Repository preparation failed for pre-commit")
                 output["text"] = self.check_run_handler.get_check_run_text(out=_res[1], err=_res[2])
                 return await self.check_run_handler.set_run_pre_commit_check_failure(output=output)
 
+            self.logger.step(f"{self.log_prefix} Executing pre-commit command")  # type: ignore
             rc, out, err = await run_command(command=cmd, log_prefix=self.log_prefix)
 
             output["text"] = self.check_run_handler.get_check_run_text(err=err, out=out)
 
             if rc:
+                self.logger.step(f"{self.log_prefix} Pre-commit checks completed successfully")  # type: ignore
                 return await self.check_run_handler.set_run_pre_commit_check_success(output=output)
             else:
+                self.logger.step(f"{self.log_prefix} Pre-commit checks failed")  # type: ignore
                 return await self.check_run_handler.set_run_pre_commit_check_failure(output=output)
 
     async def run_build_container(
@@ -255,6 +279,8 @@ class RunnerHandler:
         if not self.github_webhook.build_and_push_container:
             return
 
+        self.logger.step(f"{self.log_prefix} Starting container build process")  # type: ignore
+
         if (
             self.owners_file_handler
             and reviewed_user
@@ -271,6 +297,7 @@ class RunnerHandler:
             if await self.check_run_handler.is_check_run_in_progress(check_run=BUILD_CONTAINER_STR) and not is_merged:
                 self.logger.info(f"{self.log_prefix} Check run is in progress, re-running {BUILD_CONTAINER_STR}.")
 
+        self.logger.step(f"{self.log_prefix} Setting container build check status to in-progress")  # type: ignore
         await self.check_run_handler.set_container_build_in_progress()
 
         _container_repository_and_tag = self.github_webhook.container_repository_and_tag(
@@ -291,6 +318,7 @@ class RunnerHandler:
 
         podman_build_cmd: str = f"podman build {build_cmd}"
         self.logger.debug(f"{self.log_prefix} Podman build command to run: {podman_build_cmd}")
+        self.logger.step(f"{self.log_prefix} Preparing repository clone for container build")  # type: ignore
         async with self._prepare_cloned_repo_dir(
             pull_request=pull_request,
             is_merged=is_merged,
@@ -307,22 +335,27 @@ class RunnerHandler:
                 if pull_request and set_check:
                     return await self.check_run_handler.set_container_build_failure(output=output)
 
+            self.logger.step(f"{self.log_prefix} Executing container build command")  # type: ignore
             build_rc, build_out, build_err = await self.run_podman_command(command=podman_build_cmd)
             output["text"] = self.check_run_handler.get_check_run_text(err=build_err, out=build_out)
 
             if build_rc:
+                self.logger.step(f"{self.log_prefix} Container build completed successfully")  # type: ignore
                 self.logger.info(f"{self.log_prefix} Done building {_container_repository_and_tag}")
                 if pull_request and set_check:
                     return await self.check_run_handler.set_container_build_success(output=output)
             else:
+                self.logger.step(f"{self.log_prefix} Container build failed")  # type: ignore
                 self.logger.error(f"{self.log_prefix} Failed to build {_container_repository_and_tag}")
                 if pull_request and set_check:
                     return await self.check_run_handler.set_container_build_failure(output=output)
 
             if push and build_rc:
+                self.logger.step(f"{self.log_prefix} Starting container push to registry")  # type: ignore
                 cmd = f"podman push --creds {self.github_webhook.container_repository_username}:{self.github_webhook.container_repository_password} {_container_repository_and_tag}"
                 push_rc, _, _ = await self.run_podman_command(command=cmd)
                 if push_rc:
+                    self.logger.step(f"{self.log_prefix} Container push completed successfully")  # type: ignore
                     push_msg: str = f"New container for {_container_repository_and_tag} published"
                     if pull_request:
                         await asyncio.to_thread(pull_request.create_issue_comment, push_msg)
@@ -357,12 +390,16 @@ class RunnerHandler:
         if not self.github_webhook.pypi:
             return
 
+        self.logger.step(f"{self.log_prefix} Starting Python module installation")  # type: ignore
+
         if await self.check_run_handler.is_check_run_in_progress(check_run=PYTHON_MODULE_INSTALL_STR):
             self.logger.info(f"{self.log_prefix} Check run is in progress, re-running {PYTHON_MODULE_INSTALL_STR}.")
 
         clone_repo_dir = f"{self.github_webhook.clone_repo_dir}-{uuid4()}"
         self.logger.info(f"{self.log_prefix} Installing python module")
+        self.logger.step(f"{self.log_prefix} Setting Python module install check status to in-progress")  # type: ignore
         await self.check_run_handler.set_python_module_install_in_progress()
+        self.logger.step(f"{self.log_prefix} Preparing repository clone for Python module installation")  # type: ignore
         async with self._prepare_cloned_repo_dir(
             pull_request=pull_request,
             clone_repo_dir=clone_repo_dir,
@@ -376,6 +413,7 @@ class RunnerHandler:
                 output["text"] = self.check_run_handler.get_check_run_text(out=_res[1], err=_res[2])
                 return await self.check_run_handler.set_python_module_install_failure(output=output)
 
+            self.logger.step(f"{self.log_prefix} Executing Python module installation command")  # type: ignore
             rc, out, err = await run_command(
                 command=f"uvx pip wheel --no-cache-dir -w {clone_repo_dir}/dist {clone_repo_dir}",
                 log_prefix=self.log_prefix,
@@ -384,11 +422,18 @@ class RunnerHandler:
             output["text"] = self.check_run_handler.get_check_run_text(err=err, out=out)
 
             if rc:
+                self.logger.step(f"{self.log_prefix} Python module installation completed successfully")  # type: ignore
                 return await self.check_run_handler.set_python_module_install_success(output=output)
 
+            self.logger.step(f"{self.log_prefix} Python module installation failed")  # type: ignore
             return await self.check_run_handler.set_python_module_install_failure(output=output)
 
     async def run_conventional_title_check(self, pull_request: PullRequest) -> None:
+        if not self.github_webhook.conventional_title:
+            return
+
+        self.logger.step(f"{self.log_prefix} Starting conventional title check")  # type: ignore
+
         output: dict[str, str] = {
             "title": "Conventional Title",
             "summary": "",
@@ -398,16 +443,19 @@ class RunnerHandler:
         if await self.check_run_handler.is_check_run_in_progress(check_run=CONVENTIONAL_TITLE_STR):
             self.logger.info(f"{self.log_prefix} Check run is in progress, re-running {CONVENTIONAL_TITLE_STR}.")
 
+        self.logger.step(f"{self.log_prefix} Setting conventional title check status to in-progress")  # type: ignore
         await self.check_run_handler.set_conventional_title_in_progress()
         allowed_names = self.github_webhook.conventional_title.split(",")
         title = pull_request.title
+
         self.logger.debug(f"{self.log_prefix} Conventional title check for title: {title}, allowed: {allowed_names}")
-        if any([title.startswith(f"{_name}:") for _name in allowed_names]):
+        if any([re.search(rf"{_name}(.*):", title) for _name in allowed_names]):
+            self.logger.step(f"{self.log_prefix} Conventional title check completed successfully")  # type: ignore
             await self.check_run_handler.set_conventional_title_success(output=output)
         else:
+            self.logger.step(f"{self.log_prefix} Conventional title check failed")  # type: ignore
             output["summary"] = "Failed"
             output["text"] = f"Pull request title must starts with allowed title: {': ,'.join(allowed_names)}"
-
             await self.check_run_handler.set_conventional_title_failure(output=output)
 
     async def is_branch_exists(self, branch: str) -> Branch:
@@ -415,15 +463,18 @@ class RunnerHandler:
 
     async def cherry_pick(self, pull_request: PullRequest, target_branch: str, reviewed_user: str = "") -> None:
         requested_by = reviewed_user or "by target-branch label"
+        self.logger.step(f"{self.log_prefix} Starting cherry-pick process to {target_branch}")  # type: ignore
         self.logger.info(f"{self.log_prefix} Cherry-pick requested by user: {requested_by}")
 
         new_branch_name = f"{CHERRY_PICKED_LABEL_PREFIX}-{pull_request.head.ref}-{shortuuid.uuid()[:5]}"
         if not await self.is_branch_exists(branch=target_branch):
             err_msg = f"cherry-pick failed: {target_branch} does not exists"
+            self.logger.step(f"{self.log_prefix} Cherry-pick failed: target branch does not exist")  # type: ignore
             self.logger.error(err_msg)
             await asyncio.to_thread(pull_request.create_issue_comment, err_msg)
 
         else:
+            self.logger.step(f"{self.log_prefix} Setting cherry-pick check status to in-progress")  # type: ignore
             await self.check_run_handler.set_cherry_pick_in_progress()
             commit_hash = pull_request.merge_commit_sha
             commit_msg_striped = pull_request.title.replace("'", "")
@@ -452,9 +503,11 @@ class RunnerHandler:
                     output["text"] = self.check_run_handler.get_check_run_text(out=_res[1], err=_res[2])
                     await self.check_run_handler.set_cherry_pick_failure(output=output)
 
+                self.logger.step(f"{self.log_prefix} Executing cherry-pick commands")  # type: ignore
                 for cmd in commands:
                     rc, out, err = await run_command(command=cmd, log_prefix=self.log_prefix)
                     if not rc:
+                        self.logger.step(f"{self.log_prefix} Cherry-pick command failed")  # type: ignore
                         output["text"] = self.check_run_handler.get_check_run_text(err=err, out=out)
                         await self.check_run_handler.set_cherry_pick_failure(output=output)
                         self.logger.error(f"{self.log_prefix} Cherry pick failed: {out} --- {err}")
@@ -477,6 +530,7 @@ class RunnerHandler:
 
             output["text"] = self.check_run_handler.get_check_run_text(err=err, out=out)
 
+            self.logger.step(f"{self.log_prefix} Cherry-pick completed successfully")  # type: ignore
             await self.check_run_handler.set_cherry_pick_success(output=output)
             await asyncio.to_thread(
                 pull_request.create_issue_comment, f"Cherry-picked PR {pull_request.title} into {target_branch}"
