@@ -2,12 +2,12 @@ import os
 
 import pytest
 import yaml
-from simple_logger.logger import logging
 from starlette.datastructures import Headers
 
 from webhook_server.libs.owners_files_handler import OwnersFileHandler
 
 os.environ["WEBHOOK_SERVER_DATA_DIR"] = "webhook_server/tests/manifests"
+os.environ["ENABLE_LOG_SERVER"] = "true"
 from webhook_server.libs.github_api import GithubWebhook
 
 
@@ -122,10 +122,16 @@ def github_webhook(mocker, request):
     mocker.patch(f"{base_import_path}.get_github_repo_api", return_value=Repository())
     mocker.patch(f"{base_import_path}.GithubWebhook.add_api_users_to_auto_verified_and_merged_users", return_value=None)
 
+    # Use standard Python logger for caplog compatibility
+    import logging as python_logging
+
+    test_logger = python_logging.getLogger("GithubWebhook")
+    test_logger.setLevel(python_logging.DEBUG)
+
     process_github_webhook = GithubWebhook(
         hook_data={"repository": {"name": Repository().name, "full_name": Repository().full_name}},
         headers=Headers({"X-GitHub-Event": "test-event"}),
-        logger=logging.getLogger(),
+        logger=test_logger,
     )
     owners_file_handler = OwnersFileHandler(github_webhook=process_github_webhook)
 
@@ -140,3 +146,53 @@ def process_github_webhook(github_webhook):
 @pytest.fixture(scope="function")
 def owners_file_handler(github_webhook):
     return github_webhook[1]
+
+
+# === Performance Optimization Fixtures ===
+
+
+@pytest.fixture
+def sample_log_entries():
+    """Pre-generated sample log entries for performance tests."""
+    from datetime import datetime, timedelta
+
+    from webhook_server.libs.log_parser import LogEntry
+
+    entries = []
+    base_time = datetime(2025, 7, 31, 10, 0, 0)
+
+    for i in range(100):
+        entries.append(
+            LogEntry(
+                timestamp=base_time + timedelta(seconds=i),
+                level="INFO",
+                logger_name="GithubWebhook",
+                message=f"Test log entry {i}",
+                hook_id=f"test-hook-{i}",
+                repository=f"test-repo-{i % 10}",
+                event_type="push" if i % 2 == 0 else "pull_request",
+                github_user="test-user",
+                pr_number=i if i % 3 == 0 else None,
+            )
+        )
+
+    return entries
+
+
+@pytest.fixture(autouse=True)
+def optimize_test_environment():
+    """Auto-applied fixture to optimize test environment."""
+    import logging as python_logging
+
+    # Disable unnecessary logging during tests
+    python_logging.getLogger("httpx").setLevel(python_logging.WARNING)
+    python_logging.getLogger("asyncio").setLevel(python_logging.WARNING)
+
+    # Set optimal test timeouts
+    original_timeout = os.environ.get("PYTEST_TIMEOUT", "60")
+    os.environ["PYTEST_TIMEOUT"] = "30"
+
+    yield
+
+    # Restore original timeout
+    os.environ["PYTEST_TIMEOUT"] = original_timeout
